#
# spec file for package cmus
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2007-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without sndio
Name:           cmus
Version:        2.12.0
Release:        1.3
Summary:        Text-mode music player
License:        GPL-2.0-only
Group:          Productivity/Multimedia/Sound/Players
URL:            https://cmus.github.io/
Source:         https://github.com/cmus/cmus/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  libmpcdec-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa) >= 1.0.11
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcue)
BuildRequires:  pkgconfig(libdiscid)
BuildRequires:  pkgconfig(libmikmod)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(libpulse) >= 0.9.19
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(wavpack)
Recommends:     %{name}-plugin-cue = %{version}-%{release}
Recommends:     %{name}-plugin-ffmpeg = %{version}-%{release}
# cmus has problems with lavf and 24-bit audio
Recommends:     %{name}-plugin-flac = %{version}-%{release}
Recommends:     %{name}-plugin-pulse = %{version}-%{release}
%if %{with sndio}
BuildRequires:  sndio-devel
%endif

%description
C* Music Player is a small and fast text mode (ncurses-based) music player
for Unix-like operating systems.

%package plugin-libao
Summary:        Libao output plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-libao
This package provides libao output support for the C* Music Player.

%package plugin-jack
Summary:        JACK output plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-jack
This package provides JACK output support for the C* Music Player.

%package plugin-pulse
Summary:        Pulseaudio output plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-pulse
This package provides PulseAudio output support for the C* Music Player.

%if %{with sndio}
%package plugin-sndio
Summary:        Sndio output plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-sndio
This package provides sndio output support for the C* Music Player.
%endif

%package plugin-cdio
Summary:        CDIO plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-cdio
This package provides CDIO support for the C* Music Player.

%package plugin-cue
Summary:        CUE input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-cue
This package provides CUE sheet support for the C* Music Player.

%package plugin-ffmpeg
Summary:        FFmpeg input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
Obsoletes:      %{name}-plugin-aac
Obsoletes:      %{name}-plugin-mad

%description plugin-ffmpeg
This package provides FFmpeg input support for the C* Music Player.

%package plugin-flac
Summary:        FLAC input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-flac
This package provides FLAC input support for the C* Music Player.

%package plugin-vorbis
Summary:        Vorbis input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-vorbis
This package provides Vorbis input support for the C* Music Player.

%package plugin-mikmod
Summary:        MikMod input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-mikmod
This package provides MikMod (tracker) input support for the C* Music Player.

%package plugin-modplug
Summary:        Modplug input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-modplug
This package provides modplug (tracker) input support for the C* Music Player.

%package plugin-mpc
Summary:        MPC (Musepack) input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-mpc
This package provides MPC (Musepack) input support for the C* Music Player.

%package plugin-opus
Summary:        Opus input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-opus
This package provides Opus input support for the C* Music Player.

%package plugin-wavpack
Summary:        WavPack input plugin for the C* Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}

%description plugin-wavpack
This package provides WavPack input support for the C* Music Player.

%package plugins-all
Summary:        Installs all %{name} plugins
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-plugin-cdio = %{version}-%{release}
Requires:       %{name}-plugin-cue = %{version}-%{release}
Requires:       %{name}-plugin-ffmpeg = %{version}-%{release}
Requires:       %{name}-plugin-flac = %{version}-%{release}
Requires:       %{name}-plugin-jack = %{version}-%{release}
Requires:       %{name}-plugin-libao = %{version}-%{release}
Requires:       %{name}-plugin-mikmod = %{version}-%{release}
Requires:       %{name}-plugin-modplug = %{version}-%{release}
Requires:       %{name}-plugin-mpc = %{version}-%{release}
Requires:       %{name}-plugin-opus = %{version}-%{release}
Requires:       %{name}-plugin-pulse = %{version}-%{release}
Requires:       %{name}-plugin-vorbis = %{version}-%{release}
Requires:       %{name}-plugin-wavpack = %{version}-%{release}
BuildArch:      noarch
%if %{with sndio}
Requires:       %{name}-plugin-sndio = %{version}-%{release}
%endif

%description plugins-all
This package pulls in all the plugins for the C* Music Player.

%prep
%autosetup -p1

%build
# not autoconf
./configure \
    prefix="%{_prefix}" \
    bindir="%{_bindir}" \
    datadir="%{_datadir}" \
    libdir="%{_libdir}" \
    mandir="%{_mandir}" \
    exampledir="%{_docdir}/%{name}.xxx/examples" \
%if %{with sndio}
    CONFIG_SNDIO=y \
%endif
    CONFIG_{ALSA,AO,CDDB,CDIO,CUE,DISCID,FFMPEG,FLAC,JACK,MIKMOD,MODPLUG,MPC,MPRIS,OPUS,OSS,PULSE,SAMPLERATE,VORBIS,WAVPACK,WAV}=y \
    CONFIG_{AAC,ARTS,COREAUDIO,MAD,BASS,MP4,ROAR,SUN,TREMOR,VTX,WAVEOUT}=n \
    USE_FALLBACK_IP=y \
    CFLAGS="%{optflags}"

%make_build

%install
%make_install
rm -rfv "%{buildroot}%{_docdir}/%{name}.xxx"
chmod 0644 cmus-status-display

cat<<EOF >README.plugins-all
This subpackage is empty but requires all the available %{name} plugin packages
EOF

%files
%license COPYING
%doc AUTHORS README.md
%doc cmus-status-display
%{_bindir}/cmus
%{_bindir}/cmus-remote
%dir %{_libdir}/cmus
%dir %{_libdir}/cmus/ip
%{_libdir}/cmus/ip/wav.so
%dir %{_libdir}/cmus/op
%{_libdir}/cmus/op/alsa.so
%{_libdir}/cmus/op/oss.so
%dir %{_datadir}/cmus
%{_datadir}/cmus/*.theme
%config(noreplace) %{_datadir}/cmus/rc
%{_mandir}/man1/cmus*.1%{?ext_man}
%{_mandir}/man7/cmus-tutorial.7%{?ext_man}

%files plugin-libao
%{_libdir}/cmus/op/ao.so

%files plugin-jack
%{_libdir}/cmus/op/jack.so

%files plugin-pulse
%{_libdir}/cmus/op/pulse.so

%if %{with sndio}
%files plugin-sndio
%{_libdir}/cmus/op/sndio.so
%endif

%files plugin-cdio
%{_libdir}/cmus/ip/cdio.so

%files plugin-cue
%{_libdir}/cmus/ip/cue.so

%files plugin-flac
%{_libdir}/cmus/ip/flac.so

%files plugin-vorbis
%{_libdir}/cmus/ip/vorbis.so

%files plugin-ffmpeg
%{_libdir}/cmus/ip/ffmpeg.so

%files plugin-mikmod
%{_libdir}/cmus/ip/mikmod.so

%files plugin-modplug
%{_libdir}/cmus/ip/modplug.so

%files plugin-mpc
%{_libdir}/cmus/ip/mpc.so

%files plugin-opus
%{_libdir}/cmus/ip/opus.so

%files plugin-wavpack
%{_libdir}/cmus/ip/wavpack.so

%files plugins-all
%doc README.plugins-all

%changelog
* Tue Nov 12 2024 Mia Herkt <mia@0x0.st>
- Update to 2.12.0
  * Fix possible null dereference when continue_album=0
    gh#cmus/cmus#1351
  * Make PART / PARTNUMBER aliases for DISCNUMBER
    gh#cmus/cmus#1316
  * cmus-tutorial </> is actually ,/.
    gh#cmus/cmus#1355
  * Fix potential double-close in ip/mad
    gh#cmus/cmus#1350
  * Fix view segv in rc config
    gh#cmus/cmus#1326
  * Fix pause_on_output_change not working when softvol is enabled
    gh#cmus/cmus#1353
  * Trim gaps from mp4 playback
    gh#cmus/cmus#1320
  * Show some context when editing middle of long cmdline
    gh#cmus/cmus#1319
  * Remember playlist position when resume=true
    gh#cmus/cmus#1325
  * Make trackwin heading format configurable, etc.
    gh#cmus/cmus#1317
  * Show recognized names in message for bad option value
    gh#cmus/cmus#1356
  * Draw progress bar in statusline
    gh#cmus/cmus#1318
  * Fix manpage indentation
    gh#cmus/cmus#1362
  * Fix documentation for passwd config option
    gh#cmus/cmus#1361
  * [FFmpeg] Add .dsf to extension list (DSD support)
    gh#cmus/cmus#1336
  * Fix tree restricted search infinite wrap
    gh#cmus/cmus#1371
  * Fix a couple of wrong *_attr defaults
    gh#cmus/cmus#1372
  * Fix load command args
    gh#cmus/cmus#1373
  * Rename 'Priority' to 'Default Priority' in --plugins
    gh#cmus/cmus#1365
  * Prevent search from wrapping infinitely
    gh#cmus/cmus#1370
  * add play_queue total_time
    gh#cmus/cmus#1309
  * Fully remove libcue
    gh#cmus/cmus#1378
  * Fix :mark on playlist view so filter is used
    gh#cmus/cmus#904
  * Implement option to start searches at the current position
    gh#cmus/cmus#1376
  * Apply new formats from #1317 on upgrade
    gh#cmus/cmus#1382
* Sat May 25 2024 Mia Herkt <mia@0x0.st>
- Update to 2.11.0
  * Add support for .nomedia file
    gh#cmus/cmus#1190
  * Fix a typo in an error message
    gh#cmus/cmus#1206
  * Take opus output gain into account when checking
    replaygain_limit peak
    gh#cmus/cmus#1201
  * #1219: Update Unofficial IRC channel
    gh#cmus/cmus#1220
  * Recognize artist/album sort keys from ffmpeg plugin
    gh#cmus/cmus#1165
  * Fix missing combining marks on last character in a field
    gh#cmus/cmus#1151
  * Use wcwidth for u_char_width
    gh#cmus/cmus#1198
  * Fix under-allocation when many zero-width characters are
    present
    gh#cmus/cmus#1152
  * Draw title and command lines on first update
    gh#cmus/cmus#1257
  * Switch to -latest os in build workflow
    gh#cmus/cmus#1265
  * ip/mp4: Use MP4FindTrackId() rather than assuming it's "1"
    gh#cmus/cmus#1255
  * Remove AV_CODEC_{CAP,FLAG}_TRUNCATED for FFmpeg 6 compatibility
    gh#cmus/cmus#1254
  * Introduce basu as an option for MPRIS control
    gh#cmus/cmus#1221
  * Add auto_hide_playlists_panel option
    gh#cmus/cmus#1238
  * Fixed zsh autocompletion for --query/-Q
    gh#cmus/cmus#1244
  * Search should only try filename when there are no tags
    gh#cmus/cmus#1263
  * Ignore duplicates when adding tracks to the library
    gh#cmus/cmus#1052
  * Implement pl_env_vars option for library/playlist/cache
    relocation
    gh#cmus/cmus#1085
  * pulse: don't drain the stream
    gh#cmus/cmus#1268
  * Fixed function detection. check_function failed to compile due
    to clang -Wint-conversion warning became error.
    gh#cmus/cmus#1269
  * Support italic text
    gh#cmus/cmus#1179
  * Flag to prevent cycling with left-view / right-view
    gh#cmus/cmus#1275
  * Add mouse bindings for right third of status bar
    gh#cmus/cmus#1272
  * Implement option to ignore pasted text in normal mode
    gh#cmus/cmus#1271
  * Add option to sort albums
    gh#cmus/cmus#1276
  * Check only title in track title replacement
    gh#cmus/cmus#1281
  * Add %%{totaldiscs} to available format string
    gh#cmus/cmus#1294
  * [FFmpeg] Switch to new channel layout api
    gh#cmus/cmus#1292
  * Reduce R128 gain precision to 2 places of decimal
    gh#cmus/cmus#1291
  * Fix formatting of whole number doubles
    gh#cmus/cmus#1290
  * Fix unmute when using softvol
    gh#cmus/cmus#1279
  * Allow cue plugin to parse cue sheet with multiple files.
    gh#cmus/cmus#1300
  * Add commands for external playlist management
    gh#cmus/cmus#1297
  * Fix gbuf to account for print width of control characters
    gh#cmus/cmus#1289
  * Fix player-next-album / player-prev-album with play_sorted
    gh#cmus/cmus#1277
  * Fix ignore_duplicates missing filtered tracks
    gh#cmus/cmus#1288
  * Parse LAME header when mp3 was created with libavcodec
    gh#cmus/cmus#1321
  * Support 384kHz sample rates
    gh#cmus/cmus#1314
- Drop ffmpeg-6-compat.patch
* Wed May 24 2023 Mia Herkt <mia@0x0.st>
- Add ffmpeg-6-compat.patch
  See https://github.com/cmus/cmus/pull/1254
* Fri Jul  8 2022 Mia Herkt <mia@0x0.st>
- Update to 2.10.0
  * Implement smart ReplayGain setting
    (gh#cmus/cmus#1049)
  * Start from end on player-prev with no current track
  * Add reshuffle when current track has disappeared
  * Make tracks hold shuffle info
  * Use a direct album reference in AAA filter
  * Add an album shuffle mode
  * Add "player-next-album" and "player-prev-album" commands
  * Rename "shuffle" command to "reshuffle"
  * Reset position in shuffle list after a manual reshuffle
  * Fixes channel map for multichannel flac files
    (gh#cmus/cmus#1072)
  * Replaces improper fcntl with ioctl in op/oss
    (gh#cmus/cmus#1104)
  * Initialize active to zero in print_editable
    (gh#cmus/cmus#1093 gh#cmus/cmus#1094)
  * Allow output plugins to have multiple mixer FD lists
  * Preserve compatibility with ABI v1 output plugins
  * Implement pause_on_output_change option
    (gh#cmus/cmus#1139)
  * Implement MIXER_FDS_OUTPUT for pulse
    (gh#cmus/cmus#1139)
  * Handle colors in active windows correctly
    (gh#cmus/cmus#1120)
  * Initialize window size in init_curses
    (gh#cmus/cmus#1119)
  * ip/ffmpeg.c: fix send/receive API usage
    (gh#cmus/cmus#1080)
  * Indicate elided text with "…" & related formatting tweaks
    (gh#cmus/cmus#1051)
  * Limit max draw width to 1023 columns
    (gh#cmus/cmus#1065)
  * spotify.theme
    (gh#cmus/cmus#1123)
  * A few typo/style fixes to the manpages
    (gh#cmus/cmus#1150)
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 2.9.1:
  * Documentation improvements for keybindings and some commands
  * Spelling, grammar, and other improvements
  * Add comments about fg/bg color to gruvbox-warm.theme
  * Increase help view keybinding width
  * pgaskin and flyingmutant committed 11 days ago
  * ip/cdio.c: only declare track_comments_found if
  * Remove unused functions in op/sndio.c
  * Fixes truncation warnings by replacing %%s with %%.s
  * add amazon.theme (#975)
  * Fix playlist track selection
* Sun Jan  3 2021 9@cirno.systems
- Update to version 2.8.0~20210101.gcef5ea4:
  * Switch to GitHub Actions (#1026)
  * Shuffle first track (#893) (#1008)
  * Implement mouse events for title bar (#1025)
  * Fix whitespace issues (#1021)
* Wed Dec 16 2020 9@cirno.systems
- Update to version 2.8.0~20201215.gba1c3f0:
  * Implement mouse events for status bar (#1013)
  * Add tree width options (#1018)
  * Stop after queue (resolves #696) (#1006)
  * play pregaps of songs by adding them at the end of the previous song (#983)
  * properly calculate size of print string (#987)
  * Support R128_TRACK_GAIN / R128_ALBUM_GAIN tags (#994)
  * Adding "--server SOCKET --passwd PASSWORD" section (#958)
  * Add -n option to win-add-{l,p,Q,q} to prevent selecting the next item (#1017)
  * Add support for 'DISCNUMBER' REM-field in CUE-sheets (#982)
  * Add -f, --file to cmus-remote (#984)
  * Add gruvbox-warm.theme (#1014)
  * Update zsh completion (#985) (#1019)
  * Make mouse behavior on playlist window consistent with library (#1011)
  * Fix type of MPRIS2 fields title and album (#972)
  * docs: fix simple typo, speacial -> special (#1002)
* Fri Apr 10 2020 9@cirno.systems
- Update to version 2.8.0~20200120.gd1290d5:
  * Fix bug on ppc64 caused by narrowing cast (#941)
  * Fix typo: it's->its (#947)
* Tue Nov 26 2019 9@cirno.systems
- Clean up spec file
- Update to version 2.8.0~20191105.g354625c:
  * Allow push to accept no arguments (#937)
  * mute/unmute command (#934)
  * Add `continue_album` option (#927)
  * Fix a crash when moving all tracks in a view (#916)
  * fixed playlist name searching (#906)
  * misc_init: remove variable user_name (#898)
  * Makes :quit only prompt if -i is given (#888)
  * ip/mp4: add metadata support for bpm/tempo (#878)
* Sat Feb 23 2019 9@cirno.systems
- Update to version 2.8.0~20190219.ge27e813:
  * Ensures all data sent on dbus is in utf8 (#847) (#871)
  * bits-per-sample fixes (#870)
  * Fixes incorect bit rate declaration for 24bit flac (#867)
  * Changes yes_no_query to signal error on cmus exit (#858)
  * Add support for elogind (#846)
  * ip/ffmpeg: enable opus support (#865)
  * Add note about overriding keybindings using rc (closes #742) (#866)
  * Avoid -I$(pwd) (#820)
  * Fixes ffmpeg deprecations (#861)
  * Add *.lo to clean in Makefile (#864)
  * Fixes various compiler warning (#862)
  * added "exiting" player status (#648)
  * Makes save -p consistent with documentation (#859)
  * Make cmus-update*.py use env python and fix pidgin with py3 (#857)
  * cmus 2.8.0
  * README: note that cmus is not actively maintained
  * Fix CI build by specifying gcc version for Linux. Add OSX to CI test (#854)
  * Increasing print buffer to fix crashes on ultra wide screens (#853)
* Wed Dec  5 2018 9@cirno.systems
- Update to version 2.8.0~20181120.gf5a442a:
  * Change to get_non_empty_env for CMUS_PLAYLIST_DIR. (#836)
  * Add support for CMUS_PLAYLIST_DIR. (#830)
  * Add documentation for passwd option (#824)
  * Accept PARTOFACOMPILATION tag (#807)
* Wed May 30 2018 9@cirno.systems
- Update to version 2.8.0~20180524.g8cccf70:
  * Skip track when seeking past track duration (#803)
* Sun Apr 22 2018 9@cirno.systems
- Update to version 2.8.0~20180422.gb595b8c:
  * Fix ffmpeg plugin build (#793)
  * Correct parsing for cue files with byte order mark (#774)
  * Add dracula theme
  * Add albumartist to status_display_program.
  * options: add color_win_cur_attr
  * Add command to raise VTE window + implement MPRIS Raise method
  * Don't call mpris_seeked from within the player
  * Make player_set_op accept an owned string
  * Add the delegate series of functions
  * Make most player functions delegated
* Wed Jan 31 2018 olaf@aepfle.de
- Adjust usage of gccN for Leap42 and SLE12
* Wed Nov  1 2017 9@cirno.systems
- Update to version 2.8.0~20171019.g3a4ce9c:
  * Add version command (#733)
  * handle "REM COMPILATION TRUE" in cue generated by XLD
  * Make ^U/^D default for half-page up/down motions
  * Remove double-inclusion of stdatomic header
* Mon Jul 10 2017 olaf@aepfle.de
- Use the detected gccN
- Add bcond for sndio
* Sun Jul  2 2017 9@cirno.systems
- Update to version 2.8.0~20170702.g61d4b2b:
  * Fixed `status_display_program` being called only once when
    "repeat current" is set
* Thu Jun 29 2017 olaf@aepfle.de
- Adjust usage of gccN for Leap42 and SLE12
* Wed Jun 21 2017 9@cirno.systems
- Update to version 2.8.0~20170505.g0da3472:
  * Fixed Linux kernel style link
  * Enable tilde expansion for :player-play
  * Make flac do sample rate accurrate seek
  * fix cue rounding to make it sample rate accurate
  * Expose stream info via MPRIS
  * added D-Bus (MPRIS) section to man page
  * Add some trailing commas
  * made album color in trackwin configurable
  * Fix MPRIS CanGoPrevious property typo
* Fri Feb 24 2017 olaf@aepfle.de
- Remove mp4 plugin
* Mon Sep 21 2015 olaf@aepfle.de
- Update to version 2.7.1
* Mon Sep 21 2015 olaf@aepfle.de
- Convert to BuildRequires pkgconfig, enable libcue,opus,roar support
* Tue Feb 10 2015 avvissu@yandex.ru
- add cdio plugin
* Wed Nov  5 2014 p.seiler@linuxmail.org
- update to version 2.6.0:
  Major new features:
  * show all tracks when artist is selected in the tree view
  * JACK output plugin
  * Opus input plugin
  Other notable new things:
  * «Night» and «Solarized» color schemes
  * reverse sort order support
  * ReplayGain closer to the spec
  * vim-style <c-e> / <c-y> scrolling
  * follow option
  * show_playback_position option
  * XDG directories support
  * better support for newer versions of FFmpeg
  * support for .oga and .ogx file extensions
  * stream metadata in cmus-remote -Q
* Thu Jun 12 2014 p.seiler@linuxmail.org
- Build against ffmpeg(2) not ffmpeg1
- updated package to 2.5.1:
  * CUE sheets support. When adding e.g. `track.flac` to the library, cmus will
  check for `track.cue` or `track.flac.cue` in the same directory. If it founds
  one, it will ignore the tags in `track.flac` and use CUE metadata instead
  * cdio input plugin, for those of you who still remember what a CD is :-)
  * support for WavPack `.wvc` correction files
  * new «zenburn» color scheme (as seen at http://cmus.sf.net/), and text
  attributes (bold/reverse/…) support for UI elements
  * improved tab completion, new `scroll_offset` and `icecast_default_charset`
  options, even better tag parsing and compilations handling, and numerous small
  enhancements all over the place.
* Tue Jan 28 2014 guillaume@opensuse.org
- Build against ffmpeg1 not ffmpeg(2)
* Thu Nov  8 2012 pascal.bleser@opensuse.org
- update to 2.5.0:
  * adds CUE sheet support
  * adds cdio input plugin
  * adds support for WavPack correction files
  * adds a new "zenburn" color scheme
  * improvements to tab completion, tag parsing, and compilation handling
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- update to 2.4.3:
  * maintenance release: it mostly fixes several build and stability issues
    caused by external library changes
* Sun Jul 24 2011 pascal.bleser@opensuse.org
- update to 2.4.2:
  * several important bug and build fixes; everyone is encouraged to upgrade
* Thu May 26 2011 pascal.bleser@opensuse.org
- update to 2.4.1:
  * fixes crashes and misbehaviours
* Sun Apr 24 2011 detlef@links2linux.de
- update to 2.4.0:
  * this release features tons of improvements, with most notable ones being
    live library/playlist filtering and playback resume support
* Sun Apr 10 2011 pascal.bleser@opensuse.org
- update to 2.3.5:
  * several serious (but rarely encountered) issues have been fixed
- build with optflags
* Thu Feb 10 2011 pascal.bleser@opensuse.org
- update to 2.3.4:
  * features an ability to restore the playback volume after restart (when
    using PulseAudio output plugin)
  * adds APE files support (using the FFMPEG input plugin)
  * bugfixes
* Thu Jun 17 2010 pascal@links2linux.de
- update to 2.3.3:
  * a couple of serious bugs has been fixed, so everybody is encouraged to
    upgrade
  * support for the newest version of mp4v2 was added
* Thu Apr 15 2010 pascal@links2linux.de
- update to 2.3.2:
  * libao 1.0 compatibility issue are fixed
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- update to 2.3.1:
  * ID3 parsing was fixed
  * a minor documentation update was done
  * MP3s with broken CRC are now supported
  * a default binding was set for "q"
  * insecure /tmp usage was fixed
* Tue Mar  2 2010 pascal.bleser@opensuse.org
- update to 2.3.0
* Sat Jul 28 2007 guru@unixtech.be
- new package
